/*
 * File Name: Obstacle.cs
 * 
 * Date: 06/01/2006
 *
 * Copyright (c) 2006 Michael LaLena. All rights reserved.  (www.lalena.com)
 * Permission to use, copy, modify, and distribute this Program and its documentation,
 *  if any, for any purpose and without fee is hereby granted, provided that:
 *   (i) you not charge any fee for the Program, and the Program not be incorporated
 *       by you in any software or code for which compensation is expected or received;
 *   (ii) the copyright notice listed above appears in all copies;
 *   (iii) both the copyright notice and this Agreement appear in all supporting documentation; and
 *   (iv) the name of Michael LaLena or lalena.com not be used in advertising or publicity
 *          pertaining to distribution of the Program without specific, written prior permission. 
 */

using System.Drawing;

namespace Flock
{
	/// <summary>
	/// This obstacle class represents an item on the map that all birds try
	/// to avoid.Obstacles do not move.
	/// </summary>
	public class Obstacle : Bird
	{
		/// <summary>
		/// This is the constructor for the obstacle.
		/// </summary>
		/// <param name="x">The X coordinate of the Obstacle</param>
		/// <param name="y">The Y coordinate of the Obstacle</param>
		public Obstacle(int x, int y) : base(x, y, 0, Color.Black)
		{
		}

		/// <summary>
		/// The obstacle class overrides the move function to do nothing.
		/// </summary>
		/// <param name="angle">Not used</param>
		public override void Move(int angle)
		{
			// obstacles do not move
		}

		/// <summary>
		/// Draws the Obstacle as a simple circle
		/// </summary>
		/// <param name="g">The graphics to draw the obstacle on</param>
		public override void Draw(Graphics g)
		{
			using (var pen = new Pen(BirdColor))
			{
				g.DrawEllipse(pen, Location.X - 8, Location.Y - 8, 16, 16);
			}
		}
	}
}