/**
 * File Name: Predator.cs
 * 
 * Date: 06/01/2006
 *
 * Copyright (c) 2006 Michael LaLena. All rights reserved.  (www.lalena.com)
 * Permission to use, copy, modify, and distribute this Program and its documentation,
 *  if any, for any purpose and without fee is hereby granted, provided that:
 *   (i) you not charge any fee for the Program, and the Program not be incorporated
 *       by you in any software or code for which compensation is expected or received;
 *   (ii) the copyright notice listed above appears in all copies;
 *   (iii) both the copyright notice and this Agreement appear in all supporting documentation; and
 *   (iv) the name of Michael LaLena or lalena.com not be used in advertising or publicity
 *          pertaining to distribution of the Program without specific, written prior permission. 
 */

using System.Drawing;

namespace Flock
{
	/// <summary>
	/// The predator is a type of bird that tries to eat the other birds.
	/// Once the predator eats enough birds to satisfy its hunger, it is removed
	/// from the map.
	/// </summary>
	public class Predator : Bird
	{
		/// <summary>
		/// How many birds this predator must eat before being removed from the map.
		/// </summary>
		public int Hunger;

		/// <summary>
		/// Constructor for the predator. Places the predator at a random location
		/// </summary>
		/// <param name="x">The X coordinate of the Predator</param>
		/// <param name="y">The Y coordinate of the Predator</param>
		public Predator(int x, int y) : base(x, y, 0, Color.Red)
		{
		}

		/// <summary>
		/// Constructor for the predator. Places the predator at a random location
		/// </summary>
		public Predator() : base(Color.Red)
		{
		}

		/// <summary>
		/// Reduces the hunger value by one.
		/// </summary>
		public void EatBird()
		{
			Hunger--;
		}
	}
}